@@ -437,6 +437,35 @@ nautilus_path_bar_map (GtkWidget *widget)
 	GTK_WIDGET_CLASS (nautilus_path_bar_parent_class)->map (widget);
 }
 
+#define BUTTON_BOTTOM_SHADOW 1
+
+static void
+union_with_clip (GtkWidget *widget,
+                 gpointer   clip)
+{
+	GtkAllocation widget_clip;
+
+	if (!gtk_widget_is_drawable (widget)) {
+		return;
+	}
+
+	gtk_widget_get_clip (widget, &widget_clip);
+
+	gdk_rectangle_union (&widget_clip, clip, clip);
+}
+
+static void
+_set_simple_bottom_clip (GtkWidget *widget,
+			 gint pixels)
+{
+	GtkAllocation clip;
+
+	gtk_widget_get_allocation (widget, &clip);
+	clip.height += pixels;
+
+	gtk_container_forall (GTK_CONTAINER (widget), union_with_clip, &clip);
+	gtk_widget_set_clip (widget, &clip);
+}
 
 static void
 child_ordering_changed (NautilusPathBar *path_bar)
@@ -489,6 +518,7 @@ nautilus_path_bar_size_allocate (GtkWidget     *widget,
 
         /* No path is set so we don't have to allocate anything. */
         if (path_bar->priv->button_list == NULL) {
+		_set_simple_bottom_clip (widget, BUTTON_BOTTOM_SHADOW);
                 return;
 	}
         direction = gtk_widget_get_direction (widget);
@@ -661,6 +691,8 @@ nautilus_path_bar_size_allocate (GtkWidget     *widget,
 	if (needs_reorder) {
 		child_ordering_changed (path_bar);
 	}
+
+	_set_simple_bottom_clip (widget, BUTTON_BOTTOM_SHADOW);
 }
 
 static void
